A building-level data set combining: apartment building registry, apartment building evaluation scores, Above Guideline Increase applications, tenant defense fund grants, and eviction hearings. Used primarily as a data source for the map, in add_blank_points_layers.
1 |
An object of class sf (inherits from tbl_df, tbl, data.frame) with 4179 rows and 25 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.